@@ -277,7 +277,7 @@ edgelist_find_root = function(edgelist, genesets) {
 #' @param genesets_test_result geneset testing results; the output from `test_genesets()`
 #' @noRd
 ontology_data_structures = function(geneset_ids, genesets, genesets_test_result) {
-  name = ngenes = pvalue = parent_ngenes = child = NULL # fix invisible bindings R package NOTE
+  id = name = ngenes = pvalue = parent_ngenes = child = NULL # fix invisible bindings R package NOTE
   stopifnot("parameter geneset_ids must not be empty and contain valid genesets_test_result$id values" = length(geneset_ids) > 0 && is.character(geneset_ids) && all(geneset_ids %in% genesets_test_result$id))
   stopifnot("parameter genesets must be a geneset table. This function requires ontological structure in the genesets, represented by a 'parent_id' column (e.g. does NOT work with genesets imported in GMT format)" =
               is.data.frame(genesets) && nrow(genesets) > 0 && "parent_id" %in% colnames(genesets))
@@ -326,7 +326,7 @@ ontology_data_structures = function(geneset_ids, genesets, genesets_test_result)
 #' @param toplevel_max_ngenes groups in the treemap should not have more than this many genes ('ngenes' in geneset test results)
 #' @noRd
 build_treemap = function(ods, simplify = "none", toplevel_max_ngenes = Inf) {
-  parent = parent_pvalue = child = child_pvalue = child_name = child_ngenes = children = name = ngenes = group_ngenes = subgroup_name = NULL # fix invisible bindings R package NOTE
+  id = parent = parent_pvalue = child = child_pvalue = child_name = child_ngenes = children = name = ngenes = group_ngenes = subgroup_name = NULL # fix invisible bindings R package NOTE
   stopifnot(length(simplify) == 1 && simplify %in% c("leaf_only", "prune_singletons", "pvalue", "none"))
   stopifnot(length(toplevel_max_ngenes) == 1 && is.numeric(toplevel_max_ngenes) && !is.na(toplevel_max_ngenes) && toplevel_max_ngenes >= 0)
 
